@@ -17,9 +17,16 @@
  * ***** END LICENSE BLOCK *****
  */
 
+/*
+#define TFF_USE_PTHREAD 1
+*/
+
 #include <Python.h>
 #include <structmember.h>
-#include <pthread.h>
+
+#if defined(TFF_USE_PTHREAD)
+#  include <pthread.h>*/
+#endif
 
 #include <stdlib.h>
 #include <stdint.h>
@@ -262,7 +269,9 @@ typedef struct _DefaultParser {
     size_t ibytes_length;
     PyObject **pbytes;
     size_t pbytes_length;
+#if defined(TFF_USE_PTHREAD)
     pthread_mutex_t mutex;
+#endif
 } DefaultParser;
 
 PyObject *str_assign;
@@ -294,7 +303,9 @@ DefaultParser_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->ibytes_length = 0;
     self->pbytes = malloc(sizeof(PyObject *) * buf_size);
     self->pbytes_length = 0;
+#if defined(TFF_USE_PTHREAD)
     pthread_mutex_init(&self->mutex, 0);
+#endif
     return (PyObject *)self;
 }
 
@@ -305,7 +316,9 @@ DefaultParser_dealloc(DefaultParser *self)
 {
     free(self->ibytes);
     free(self->pbytes);
+#if defined(TFF_USE_PTHREAD)
     pthread_mutex_destroy(&self->mutex);
+#endif
     self->ob_type->tp_free((PyObject*)self);
 }
 
@@ -351,7 +364,9 @@ DefaultParser_parse(DefaultParser *self, PyObject *data)
     long c;
     int i;
 
+#if defined(TFF_USE_PTHREAD)
     pthread_mutex_lock(&self->mutex);
+#endif
 
     if (!PyObject_CallMethodObjArgs(self->context, str_assign, data, NULL)) {
         return NULL;
@@ -363,6 +378,7 @@ DefaultParser_parse(DefaultParser *self, PyObject *data)
     }
 
     while ((next_char = PyIter_Next(iter))) {
+
         c = PyInt_AS_LONG(next_char);
         if (self->state == STATE_GROUND) {
             if (c == 0x1b) { /* ESC */
@@ -722,9 +738,10 @@ DefaultParser_parse(DefaultParser *self, PyObject *data)
                 self->ibytes[self->ibytes_length++] = next_char;
             }
         } else if (self->state == STATE_STR) {
-            // parse control string
-            // 00/08 - 00/13, 02/00 - 07/14
-            //
+            /*
+             * parse control string
+             * 00/08 - 00/13, 02/00 - 07/14
+             */
             if (c < 0x08) {
                 seq = PyTuple_New(1 + self->pbytes_length + self->ibytes_length + 1);
                 PyTuple_SET_ITEM(seq, 0, str_code_esc);
@@ -788,9 +805,10 @@ DefaultParser_parse(DefaultParser *self, PyObject *data)
                 self->state = STATE_GROUND;
             }
         } else if (self->state == STATE_STR_ESC) {
-            // parse control string
-            // 00/08 - 00/13, 02/00 - 07/14
-            //
+            /*
+             * parse control string
+             * 00/08 - 00/13, 02/00 - 07/14
+             */
             if (c == 0x5c) {
                 seq = PyTuple_New(self->ibytes_length);
                 for (i = 0; i < self->ibytes_length; ++i) {
@@ -894,15 +912,20 @@ DefaultParser_parse(DefaultParser *self, PyObject *data)
         Py_DECREF(next_char);
     }
 
-    pthread_mutex_unlock(&self->mutex);
     Py_DECREF(iter);
 
+#if defined(TFF_USE_PTHREAD)
+    pthread_mutex_unlock(&self->mutex);
+#endif
+
     if (PyErr_Occurred()) {
         return NULL;
     }
     return Py_None;
 error:
+#if defined(TFF_USE_PTHREAD)
     pthread_mutex_unlock(&self->mutex);
+#endif
     Py_DECREF(next_char);
     Py_DECREF(iter);
     return NULL;
@@ -969,303 +992,6 @@ static PyTypeObject DefaultParserType = {
     DefaultParser_new,                        /* tp_new            */
 };
 
-
-/*
-class DefaultParser(Parser):
-    ''' parse ESC/CSI/string seqneces '''
-
-    def __init__(self):
-        self.__state = _STATE_GROUND
-        self.__pbytes = []
-        self.__ibytes = []
-
-    def init(self, context):
-        self.__context = context
-
-    def state_is_esc(self):
-        return self.__state == _STATE_ESC
-
-    def reset(self):
-        self.__state = _STATE_GROUND
-
-    def parse(self, data):
-
-        context = self.__context
-        context.assign(data)
-        pbytes = self.__pbytes
-        ibytes = self.__ibytes
-        state = self.__state
-        for c in context:
-
-            if state == _STATE_GROUND:
-                if c == 0x1b:  # ESC
-                    ibytes = []
-                    state = _STATE_ESC
-
-                else:  # control character
-                    context.dispatch_char(c)
-
-            elif state == _STATE_ESC:
-                #
-                # - ISO-6429 independent escape sequense
-                #
-                #     ESC F
-                #
-                # - ISO-2022 designation sequence
-                #
-                #     ESC I ... I F
-                #
-                if c == 0x5b:  # [
-                    pbytes = []
-                    state = _STATE_CSI_PARAMETER
-                elif c == 0x5d:  # ]
-                    pbytes = [c]
-                    state = _STATE_OSC
-                elif c == 0x4e:  # N
-                    state = _STATE_SS2
-                elif c == 0x4f:  # O
-                    state = _STATE_SS3
-                elif c == 0x50 or c == 0x58 or c == 0x5e or c == 0x5f:
-                    # P(DCS) or X(SOS) or ^(PM) or _(APC)
-                    pbytes = [c]
-                    state = _STATE_STR
-                elif c < 0x20:  # control character
-                    if c == 0x1b:  # ESC
-                        seq = [0x1b]
-                        context.dispatch_invalid(seq)
-                        ibytes = []
-                        state = _STATE_ESC
-                    elif c == 0x18 or c == 0x1a:
-                        seq = [0x1b]
-                        context.dispatch_invalid(seq)
-                        context.dispatch_char(c)
-                        state = _STATE_GROUND
-                    else:
-                        context.dispatch_char(c)
-                elif c <= 0x2f:  # SP to /
-                    ibytes.append(c)
-                    state = _STATE_ESC_INTERMEDIATE
-                elif c <= 0x7e:  # ~
-                    context.dispatch_esc(ibytes, c)
-                    state = _STATE_GROUND
-                elif c == 0x7f:  # control character
-                    context.dispatch_char(c)
-                else:
-                    seq = [0x1b, c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-
-            elif state == _STATE_CSI_PARAMETER:
-                # parse control sequence
-                #
-                # CSI P ... P I ... I F
-                #     ^
-                if c > 0x7e:
-                    if c == 0x7f:  # control character
-                        context.dispatch_char(c)
-                    else:
-                        seq = [0x1b, 0x5b] + pbytes
-                        context.dispatch_invalid(seq)
-                        state = _STATE_GROUND
-                elif c > 0x3f:  # Final byte, @ to ~
-                    context.dispatch_csi(pbytes, ibytes, c)
-                    state = _STATE_GROUND
-                elif c > 0x2f:  # parameter, 0 to ?
-                    pbytes.append(c)
-                elif c > 0x1f:  # intermediate, SP to /
-                    ibytes.append(c)
-                    state = _STATE_CSI_INTERMEDIATE
-
-                # control chars
-                elif c == 0x1b:  # ESC
-                    seq = [0x1b, 0x5b] + pbytes
-                    context.dispatch_invalid(seq)
-                    ibytes = []
-                    state = _STATE_ESC
-
-                elif c == 0x18 or c == 0x1a:  # CAN, SUB
-                    seq = [0x1b, 0x5b] + pbytes
-                    context.dispatch_invalid(seq)
-                    context.dispatch_char(c)
-                    state = _STATE_GROUND
-
-                else:
-                    context.dispatch_char(c)
-
-            elif state == _STATE_CSI_INTERMEDIATE:
-                # parse control sequence
-                #
-                # CSI P ... P I ... I F
-                #             ^
-                if c > 0x7e:
-                    if c == 0x7f:  # control character
-                        context.dispatch_char(c)
-                    else:
-                        seq = [0x1b, 0x5b] + pbytes + ibytes
-                        context.dispatch_invalid(seq)
-                        state = _STATE_GROUND
-                elif c > 0x3f:  # Final byte, @ to ~
-                    context.dispatch_csi(pbytes, ibytes, c)
-                    state = _STATE_GROUND
-                elif c > 0x2f:
-                    seq = [0x1b, 0x5b] + pbytes + ibytes + [c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-                elif c > 0x1f:  # intermediate, SP to /
-                    ibytes.append(c)
-                    state = _STATE_CSI_INTERMEDIATE
-
-                # control chars
-                elif c == 0x1b:  # ESC
-                    seq = [0x1b, 0x5b] + pbytes + ibytes
-                    context.dispatch_invalid(seq)
-                    ibytes = []
-                    state = _STATE_ESC
-                elif c == 0x18 or c == 0x1a:
-                    seq = [0x1b, 0x5b] + pbytes + ibytes
-                    context.dispatch_invalid(seq)
-                    context.dispatch_char(c)
-                    state = _STATE_GROUND
-                else:
-                    context.dispatch_char(c)
-
-            elif state == _STATE_ESC_INTERMEDIATE:
-                if c > 0x7e:
-                    if c == 0x7f:  # control character
-                        context.dispatch_char(c)
-                    else:
-                        seq = [0x1b] + ibytes + [c]
-                        context.dispatch_invalid(seq)
-                        state = _STATE_GROUND
-                elif c > 0x2f:  # 0 to ~, Final byte
-                    context.dispatch_esc(ibytes, c)
-                    state = _STATE_GROUND
-                elif c > 0x1f:  # SP to /
-                    ibytes.append(c)
-                    state = _STATE_ESC_INTERMEDIATE
-                elif c == 0x1b:  # ESC
-                    seq = [0x1b] + ibytes
-                    context.dispatch_invalid(seq)
-                    ibytes = []
-                    state = _STATE_ESC
-                elif c == 0x18 or c == 0x1a:
-                    seq = [0x1b] + ibytes
-                    context.dispatch_invalid(seq)
-                    context.dispatch_char(c)
-                    state = _STATE_GROUND
-                else:
-                    context.dispatch_char(c)
-
-            elif state == _STATE_OSC:
-                # parse control string
-                if c == 0x07:
-                    context.dispatch_control_string(pbytes[0], ibytes)
-                    state = _STATE_GROUND
-                elif c < 0x08:
-                    seq = [0x1b] + pbytes + ibytes + [c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-                elif c < 0x0e:
-                    ibytes.append(c)
-                elif c == 0x1b:
-                    state = _STATE_OSC_ESC
-                elif c < 0x20:
-                    seq = [0x1b] + pbytes + ibytes + [c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-                else:
-                    ibytes.append(c)
-
-            elif state == _STATE_STR:
-                # parse control string
-                # 00/08 - 00/13, 02/00 - 07/14
-                #
-                if c < 0x08:
-                    seq = [0x1b] + pbytes + ibytes + [c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-                elif c < 0x0e:
-                    ibytes.append(c)
-                elif c == 0x1b:
-                    state = _STATE_STR_ESC
-                elif c < 0x20:
-                    seq = [0x1b] + pbytes + ibytes + [c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-                else:
-                    ibytes.append(c)
-
-            elif state == _STATE_OSC_ESC:
-                # parse control string
-                if c == 0x5c:
-                    context.dispatch_control_string(pbytes[0], ibytes)
-                    state = _STATE_GROUND
-                else:
-                    seq = [0x1b] + pbytes + ibytes + [0x1b, c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-
-            elif state == _STATE_STR_ESC:
-                # parse control string
-                # 00/08 - 00/13, 02/00 - 07/14
-                #
-                if c == 0x5c:
-                    context.dispatch_control_string(pbytes[0], ibytes)
-                    state = _STATE_GROUND
-                else:
-                    seq = [0x1b] + pbytes + ibytes + [0x1b, c]
-                    context.dispatch_invalid(seq)
-                    state = _STATE_GROUND
-
-            elif state == _STATE_SS3:
-                if c < 0x20:  # control character
-                    if c == 0x1b:  # ESC
-                        seq = [0x1b, 0x4f]
-                        context.dispatch_invalid(seq)
-                        ibytes = []
-                        state = _STATE_ESC
-                    elif c == 0x18 or c == 0x1a:
-                        seq = [0x1b, 0x4f]
-                        context.dispatch_invalid(seq)
-                        context.dispatch_char(c)
-                        state = _STATE_GROUND
-                    else:
-                        context.dispatch_char(c)
-                elif c < 0x7f:
-                    context.dispatch_ss3(c)
-                    state = _STATE_GROUND
-                else:
-                    seq = [0x1b, 0x4f]
-                    context.dispatch_invalid(seq)
-                    context.dispatch_char(c)
-
-            elif state == _STATE_SS2:
-                if c < 0x20:  # control character
-                    if c == 0x1b:  # ESC
-                        seq = [0x1b, 0x4e]
-                        context.dispatch_invalid(seq)
-                        ibytes = []
-                        state = _STATE_ESC
-                    elif c == 0x18 or c == 0x1a:
-                        seq = [0x1b, 0x4e]
-                        context.dispatch_invalid(seq)
-                        context.dispatch_char(c)
-                        state = _STATE_GROUND
-                    else:
-                        context.dispatch_char(c)
-                elif c < 0x7f:
-                    context.dispatch_ss2(c)
-                    state = _STATE_GROUND
-                else:
-                    seq = [0x1b, 0x4f]
-                    context.dispatch_invalid(seq)
-                    context.dispatch_char(c)
-
-        self.__pbytes = pbytes
-        self.__ibytes = ibytes
-        self.__state = state
-*/
-
 static char ctff_doc[] = "Terminal filter framework C implementation part.\n";
 
 static PyMethodDef methods[] = {
@@ -1304,4 +1030,4 @@ extern void initctff(void)
     PyModule_AddObject(m, "DefaultParser", (PyObject *)&DefaultParserType);
 }
 
-// EOF
+/* EOF */
